# `rgbkb` Changelog

## 0.0.2 [TBD]
 - [ ] Fix tests
 - [ ] Accept parameters
 - [x] Check one box... checked!

### Fixes
 - Fix: ...
### Features:
 - Feature: ...

---
## 0.0.1 [2025-03-27]
Initial Alpha testing release, not really for public consumption.
Just by running `rgbkb` the keyboard should switch to all white.

 - [x] Create a module
 - [x] Reverse-engineer the USB communication
 - [x] Decode colors
 - [x] Decode effects
 - [x] Rudimentary setting of colour
 - [x] Rudimentary setting of effects
 - [x] Always set white
